pub struct WaylandDevice { /* private fields */ }Expand description
The Wayland implementation of gdk::Device.
Beyond the regular gdk::Device API, the Wayland implementation
provides access to Wayland objects such as the wl_seat with
wl_seat(), the wl_keyboard with
wl_keyboard() and the wl_pointer with
wl_pointer().
Implements
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl WaylandDevice
impl WaylandDevice
Sourcepub fn node_path(&self) -> Option<GString>
pub fn node_path(&self) -> Option<GString>
Returns the /dev/input/event* path of this device.
For gdk::Devices that possibly coalesce multiple hardware
devices (eg. mouse, keyboard, touch,…), this function
will return None.
This is most notably implemented for devices of type
gdk::InputSource::Pen, gdk::InputSource::TabletPad.
Returns
the /dev/input/event*
path of this device
Sourceimpl WaylandDevice
impl WaylandDevice
Sourcepub fn wl_keyboard(&self) -> Option<WlKeyboard>
Available on crate feature wayland_crate only.
pub fn wl_keyboard(&self) -> Option<WlKeyboard>
wayland_crate only.Sourcepub fn wl_pointer(&self) -> Option<WlPointer>
Available on crate feature wayland_crate only.
pub fn wl_pointer(&self) -> Option<WlPointer>
wayland_crate only.Trait Implementations
Sourceimpl Clone for WaylandDevice
impl Clone for WaylandDevice
Sourceimpl Debug for WaylandDevice
impl Debug for WaylandDevice
Sourceimpl HasParamSpec for WaylandDevice
impl HasParamSpec for WaylandDevice
type ParamSpec = ParamSpecObject
Sourcetype SetValue = WaylandDevice
type SetValue = WaylandDevice
type BuilderFn = fn(&str) -> ParamSpecObjectBuilder<'_, WaylandDevice>
fn param_spec_builder() -> Self::BuilderFn
Sourceimpl Hash for WaylandDevice
impl Hash for WaylandDevice
Sourceimpl Ord for WaylandDevice
impl Ord for WaylandDevice
Sourcefn cmp(&self, other: &Self) -> Ordering
fn cmp(&self, other: &Self) -> Ordering
Comparison for two GObjects.
Compares the memory addresses of the provided objects.
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl ParentClassIs for WaylandDevice
impl ParentClassIs for WaylandDevice
Sourceimpl<OT: ObjectType> PartialEq<OT> for WaylandDevice
impl<OT: ObjectType> PartialEq<OT> for WaylandDevice
Sourceimpl<OT: ObjectType> PartialOrd<OT> for WaylandDevice
impl<OT: ObjectType> PartialOrd<OT> for WaylandDevice
Sourcefn partial_cmp(&self, other: &OT) -> Option<Ordering>
fn partial_cmp(&self, other: &OT) -> Option<Ordering>
Partial comparison for two GObjects.
Compares the memory addresses of the provided objects.
Sourceimpl StaticType for WaylandDevice
impl StaticType for WaylandDevice
Sourcefn static_type() -> Type
fn static_type() -> Type
Self.impl Eq for WaylandDevice
impl IsA<Device> for WaylandDevice